Function XmfImage_LoadFile

pub unsafe extern "C" fn XmfImage_LoadFile(
    filename: *const c_char,
    data: *mut *mut u8,
    width: *mut u32,
    height: *mut u32,
    step: *mut u32,
) -> bool
Available on crate feature xmf only.
Performs a FFI call to XmfImage_LoadFile from the globally loaded dynamic library xmf

Safety

  • The ABI of the function must be the one we expect
  • See other preconditions in documentation of the C library