Function XmfTimeSource_System

pub unsafe extern "C" fn XmfTimeSource_System(
    param: *mut c_void,
) -> u64
Available on crate feature xmf only.
Performs a FFI call to XmfTimeSource_System from the globally loaded dynamic library xmf

Safety

  • The ABI of the function must be the one we expect
  • See other preconditions in documentation of the C library